# Welcome!

<img src="artwork/buildcat.png" width="300" style="float:right"/>

Buildcat is the elegant, minimalist render farm based on [RQ](http://python-rq.org), featuring:

* Support for any platform that can run Python.
* Thorough [documentation](https://buildcat.readthedocs.io).

You can see the full Buildcat documentation with tutorials at
https://buildcat.readthedocs.io ... for questions, comments, or suggestions, get
in touch with our team at https://gitter.im/shead-custom-design/buildcat.

License
=======

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
